Scale variable(s) mapped to the glyphs to the given range using
rescale_pal. Each variable in z gets its own
independent continuous scale.
Usage
scale_z_continuous(..., range = c(0.1, 1), z)Arguments
- ...
Additional arguments to be passed on to
continuous_scale.- range
The range to which the variable(s) specified in argument
zare to be scaled.- z
The variable(s) mapped to the glyph as a character vector.
Value
A continuous_scale object that can be added to
a ggplot object. The returned scale applies to all aesthetics named
in z simultaneously (i.e. the variables specified via cols in
the corresponding geom_*glyph() layer), rescaling their combined,
pooled range to range for use in determining glyph dimensions.