Scale variable(s) mapped to the glyphs as discrete/ordered factors. Each
variable in z gets its own independent discrete scale.
Arguments
- ...
Additional arguments to be passed on to
discrete_scale.- z
The variable(s) mapped to the glyph as a character vector or single variable name.
- na.translate
Logical. If TRUE (default), missing values are translated to "NA".
- na.value
The aesthetic value to use for missing values.
- guide
A function used to create a guide or its name. See
guidesfor more information.